#!/usr/bin/env bash

CSV_FILE="/Users/amieiro/Google Drive/Projects/talks/20240615-WC-Europe-WP-CLI-WooCommerce/docs/pasta.csv"
WORDPRESS_PATH="/Users/amieiro/code/wordpress/woocommerce"
PHOTOS_PATH="/Users/amieiro/Google Drive/Projects/talks/20240615-WC-Europe-WP-CLI-WooCommerce/photos"
ADMIN_USER="woocommerce"

# Check if the file exists
if [ ! -f "$CSV_FILE" ]; then
  echo "File not found: $CSV_FILE"
  exit 1
fi

# Convert a regular text in its slug version.
slugify() {
  local input="$1"
  echo "$input" | \
    tr '[:upper:]' '[:lower:]' | \
    sed 's/[^a-z0-9]/-/g' | \
    sed 's/--*/-/g' | \
    sed 's/^-//' | \
    sed 's/-$//'
}

# Read the CSV file
# The fields in each row are separated with |
while IFS="|" read -r name description type regular_price sku weight category image_name
do
  # Skip the header row
  if [ "$name" != "Name" ]; then
    IMAGE_FILE="${PHOTOS_PATH}/${image_name}"
    echo "Image file for this product: ${IMAGE_FILE}"

    image_id="\
      $(wp media import "${IMAGE_FILE}" \
      --alt="${name}" \
      --user="${ADMIN_USER}" \
      --path="${WORDPRESS_PATH}" \
      --porcelain)"
    echo "Id for this image: ${image_id}"

    category_id=" \
      $(wp wc product_cat list \
      --slug=$(slugify "$category") \
      --format=ids \
      --user="${ADMIN_USER}" \
      --path="${WORDPRESS_PATH}")"
    echo "Category id for this product: ${category_id}"

    wp wc product create \
      --name="${name}" \
      --description="${description}" \
      --type="${type}" \
      --regular_price="${regular_price}" \
      --sku="${sku}" \
      --weight="${weight}" \
      --categories="[ { \"id\" : ${category_id} } ]" \
      --images="[ { \"id\" : ${image_id} } ]" \
      --user="${ADMIN_USER}" \
      --path="${WORDPRESS_PATH}"    
  fi
  
  echo "---------------------------------------------"
done < "$CSV_FILE"
